@@ -14,6 +14,7 @@ import psutil
 
 logger.remove()
 # logger.add(sys.stderr, level='DEBUG')
+logger.add('./_info.log', level='INFO')
 
 global_info = {}
 
@@ -28,7 +29,7 @@ def net_io_total_bytes():
     return total_sent, total_received
 
 def monitor_info():
-    while 1:
+    while True:
         try:
             last_total_sent, last_total_received = net_io_total_bytes()
             time.sleep(1)
@@ -61,8 +62,8 @@ def monitor_info():
             global_info['系统空闲内存'] = f'{mem_free:.2f}GB'
             global_info['内存使用占比'] = f'{mem_used_percent:.2f}%'
             global_info['磁盘使用占比'] = f'{disk_used_percent:.2f}%'
-            global_info['流量出'] = f'{(sent_bytes / 1024):.2f}Kb'
-            global_info['流量入'] = f'{(received_bytes / 1024):.2f}Kb'
+            global_info['流量出'] = f'{(sent_bytes / 1024 * 8):.2f}Kbps'
+            global_info['流量入'] = f'{(received_bytes / 1024 * 8):.2f}Kbps'
         except Exception as e:
             logger.error(f'monitor_info error, {e}')
         finally:
@@ -73,15 +74,13 @@ t.start()
 
 app = Flask(__name__)
 app.config['JSON_AS_ASCII'] = False
+app.config['JSONIFY_MIMETYPE'] = 'application/json;charset=utf-8'
 
 unique_key_agent = UniqueKeyTopic()
 simple_agent = SimpleTopic()
 
 @app.route('/')
 def index():
-    cpu_usage = psutil.cpu_percent()
-    mem_used_percent = psutil.virtual_memory()[2]
-    mem_used_gb = psutil.virtual_memory()[3]/1000000000
     resp = {
         'Info': global_info,
         'Topics': {
